function varargout = ftestExample1(varargin)
%reference plane function
%AUTHOR: Jan Vanek
%the function has two modes - setup and pilot, which differ with syntax
%
%SETUP MODE:
%function select a setup of the plane - TBD
%
%Syntax in setup mode:
% setup = ftest(userData)
%   setup 1 - 25% damage boost
%   setup 2 - 25% health boost
%   setup 3 - 25% top-speed boost
%   setup 4 - 25% handling boost
%
%
%PILOT MODE
%function calculates throttle, steering, and firing values
%Syntax: [throttle, steering, firing, userData] = ftest(planes, id);
%Inputs from engine:
%   planes   - structure of all planes in the fight
%   id       - actual plane id in structure vector
%   bullets  - structure of all actual fired bullets
%Outputs to engine:
%   throttle - throttle command <0, 1>  0 minimum throttle, +1 full throttle
%   steering - steering command <-1, 1> relative steering angle (in radians)
%            positive - left, negative - right, zero - straight
%   userData - any data, which will be returned next step - universal memory
%   t        - simulation time

%SETUP MODE
if length(varargin) == 1
    varargout{1} = 1; %fixed setup - 25% damage boost
    %varargout{1} = 2; %fixed setup - 25% health boost
    %varargout{1} = 3; %fixed setup - 25% top-speed boost
    %varargout{1} = 4; %fixed setup - 25% handling boost
else
%DRIVER MODE
    if length(varargin) ~= 4
        error('Wrong number of inputs')
    end
    
    planes   = varargin{1};
    id       = varargin{2};
    bullets  = varargin{3};   
    t        = varargin{4};   
    plane    = planes(id);
    userData = plane.userData;


    %if firts run, set up steering
    if isempty(userData)
        userData = 2*rand(1)-1; %random value in <-1,1>
    end
    %throttle = 1; %full throttle all the time - harakirri style
    throttle = (id-1)/(length(planes)-1);
    steering = userData; %random but constant all the time
    %steering = 0; %straith all the time
    
    firing = rand(1) < 0.1; %random fire in 10% cases

    
    varargout{1} = throttle;
    varargout{2} = steering;
    varargout{3} = firing;
    varargout{4} = userData;    
end